@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: binary-tagged
 version: 0.1.3.0
-id: binary-tagged-0.1.3.0-8ad010d4fbb91f0378651f47b614c1f2
-key: binar_Cd2XAmznxrzL3ig1dPdB7Q
+id: binary-tagged-0.1.3.0-9f28b372dda874f24a9b6bac38e19756
+key: binar_6hGydwdeaeZAINYzAlGrzf
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/binary-tagged#readme
@@ -19,23 +19,23 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.3.0
-hs-libraries: HSbinary-tagged-0.1.3.0-Cd2XAmznxrzL3ig1dPdB7Q
+hs-libraries: HSbinary-tagged-0.1.3.0-6hGydwdeaeZAINYzAlGrzf
 depends:
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
+    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     generics-sop-0.2.0.0-419d3678c9b0f53a693a7ea2fc8ff7c9
-    hashable-1.2.4.0-44b2533f61c94bc76cb2b27e15566721
-    scientific-0.3.4.4-2c552cd0c6d8817341c76144fa370151
-    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
+    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
+    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
-    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
+    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
 haddock-html: /usr/share/doc/haskell-binary-tagged/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
